xfr

package
v0.7.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2026 License: AGPL-3.0 Imports: 18 Imported by: 0

Documentation

Overview

Package xfr handles zone transfers, an attempt to get more Hosts into the database, as the Generator itself is kind of slow.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type XFR

type XFR struct {
	// contains filtered or unexported fields
}

XFR attempts to perform zone transfers.

func New

func New(cnt int) (*XFR, error)

New returns a new XFR instance.

func (*XFR) IsActive

func (x *XFR) IsActive() bool

IsActive returns the XFR engine's active flag.

func (*XFR) Start

func (x *XFR) Start()

Start sets the XFR engine's active flag and starts the set number of worker goroutines.

func (*XFR) StartOne added in v0.4.0

func (x *XFR) StartOne()

StartOne starts an additional worker.

func (*XFR) Stop

func (x *XFR) Stop()

Stop clears the XFR engine's active flag (if set).

func (*XFR) StopOne added in v0.4.0

func (x *XFR) StopOne()

StopOne stops one worker.

func (*XFR) System added in v0.3.0

func (x *XFR) System() subsystem.ID

func (*XFR) WorkerCount added in v0.3.0

func (x *XFR) WorkerCount() int

Jump to