Documentation
¶
Overview ¶
Package xfr handles zone transfers, an attempt to get more Hosts into the database, as the Generator itself is kind of slow.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type XFR ¶
type XFR struct {
// contains filtered or unexported fields
}
XFR attempts to perform zone transfers.
func (*XFR) Start ¶
func (x *XFR) Start()
Start sets the XFR engine's active flag and starts the set number of worker goroutines.
func (*XFR) StartOne ¶ added in v0.4.0
func (x *XFR) StartOne()
StartOne starts an additional worker.
func (*XFR) WorkerCount ¶ added in v0.3.0
Click to show internal directories.
Click to hide internal directories.